#! /usr/bin/env python
# -*- coding: utf-8 -*-

"""
Module that contains tpDcc-libs-unittest constant definitions
"""

from __future__ import print_function, division, absolute_import


UNIT_TEST_VAR = 'TPDCC_UNIT_TEST'
