#! /usr/bin/env python
# -*- coding: utf-8 -*-

"""
Initialization module for tpDcc-libs-unittests
"""


def init(*args, **kwargs):
    """
    Initializes library
    :param dev: bool, Whether tpDcc-libs-qt is initialized in dev mode or not
    """

    print('Unit Test Library initialized!')
